# coding: utf-8
'''
ALTER TABLE

Add new columns, drop existing columns, renames columns, and change table properties. The command returns no results.

**Restriction:**

-   Can only rename clustering columns in the primary key.
-   Cannot change the data type of a column.
-   For a table that has a materialized view, cannot drop a column from the table even if the column is not used in the materialized view.
-   Cannot rename or drop columns that have dependent secondary indexes or Datastax Enterprise Search indexes.
-   Do not add a column with the same name as an existing column but with a different data type. It will prevent commit log replays and corrupt existing SSTables with old data.

Synopsis


ALTER TABLE [keyspace_name.]table_name 
  [ ADD ( column_definition | column_definition_list ) ]
  [ DROP ( column | column_list | COMPACT STORAGE ) ]
  [ RENAME column_name TO column_name ]
  [ WITH table_properties [ , ... ] ] ;


ADD column_defintion | ( column_definition_list )
    Add one or more columns and set the data type. Set the column name followed by the data type. The value is automatically set to null. To add multiple columns, use a comma separated list of columns placed inside parentheses.

    **Restriction:** Adding columns to a primary key is not supported after a table has been created.

DROP column | ( column_list )
    Drop one or more columns. The values contained in the row are also dropped and not recoverable. To drop multiple columns, use a comma separated list of columns placed inside parentheses.

DROP COMPACT STORAGE
    Available in DSE 5.1.6 and later, use this option only to migrate tables to a DataStax Enterprise (DSE) version that does not support COMPACT STORAGE. Removes Thrift compatibility mode from the table, which exposes the underlying structure of the Thrift table. See Migrating from compact storage.

    **Note:** Removing Thrift compatibility from a table that also has a search index disables HTTP writes and deletes-by-ID on the search index.

RENAME column_name TO column_name
    Changes the name of a primary key column and preserves the existing values.

    **Restriction:** Not supported on materialized view base-tables, or tables with secondary indexes or Datastax Enterprise Search indexes.

table_properties
    You can modify an existing table's properties. Some properties are single options that are set to a value:

    
    option_name = value [ AND ... ]
    

    Other table properties are set using a JSON map: `option_name = { subproperty_name : value [ , ... ] }`


'''
