# coding: utf-8
'''
BATCH

Applies multiple data modification language (DML) statements with atomicity and/or in isolation.

Synopsis


BEGIN [ ( UNLOGGED | COUNTER ) ] BATCH 
  [ USING TIMESTAMP [ epoch_microseconds ] ]
  dml_statement [ USING TIMESTAMP [ epoch_microseconds ] ] ;
  [ dml_statement [ USING TIMESTAMP [ epoch_microseconds ] ] [ ; ... ] ] ;
  APPLY BATCH ;


A batch can contain these dml_statements:

-   **`INSERT`**
-   **`UPDATE`**
-   **`DELETE`**

UNLOGGED | COUNTER
    If `UNLOGGED` is not specified, the batch is logged. If multiple partitions are involved, batches are logged by default. A logged batch ensures that all or none of the batch operations succeed (atomicity). First the serialized batch is written to the batchlog system table which consumes the serialized batch as blob data. After a successful write, the rows are persisted (or hinted) and the batchlog data is removed. Logging incurs a performance penalty, the batchlog is written to two other nodes. Options for thresholds, warning about or failure due to batch sizewarning about or failure due to batch size, are available.

    `UNLOGGED` runs the batch without logging penalties. Unlogged batching issues a warning when too many operations or too many partitions are involved. Single partition batch operations are unlogged by default, and are the only unlogged batch operations recommended.

    Use the `COUNTER` option for batched counter updates. Unlike other updates, counter updates are not idempotent.

USING TIMESTAMPS
    Sets the write time for transactions executed in a BATCH.

    **Restriction:**`USING TIMESTAMP` does not support LWT (lightweight transactions), such as DML statements that have an `IF NOT EXISTS` clause.


'''
